@@ -18,3 +18,7 @@ except:
 
 from pkg_resources import get_distribution, DistributionNotFound
 
+try:
+    __version__ = get_distribution('blimpy').version
+except DistributionNotFound:
+    __version__ = '0.0.0 - please install via pip/setup.py'
